@@ -7,9 +7,13 @@ from typing import Union, Dict, Any, Optional, Sequence, Mapping, Callable
 
 import numpy as np
 import torch
-from accelerate import Accelerator
+from lumo.contrib.accelerate import Accelerator
+from lumo.contrib.accelerate.utils import send_to_device
+# overwrite send_to_device to resolve https://github.com/pytorch/pytorch/issues/83015
+# from accelerate import Accelerator
+# from accelerate.utils import send_to_device
+
 from accelerate import DistributedDataParallelKwargs
-from accelerate.utils import send_to_device
 from torch import nn
 from torch.optim import Optimizer
 from torch.utils.data import DataLoader
@@ -45,13 +49,14 @@ class Trainer(_BaseTrainer):
         self.params = params
         self._logger = None
         self._saver = None
-        self.shared_prop = {}
+
         self.params.iparams()
         self.exp = TrainerExperiment(self.generate_exp_name())
 
-        self._database = TableRow(self.exp.project_name, self.exp.exp_name, self.exp.test_name_with_dist)
+        self.database = TableRow(self.exp.project_name, self.exp.exp_name, self.exp.test_name_with_dist)
         self.metric_board = Metrics(self.exp.test_root)
-
+        self.exp.dump_info('metric_board', self.metric_board.fpath)
+        self.exp.dump_info('table_row', self.database.fpath)
         self.rnd = RndManager()
 
         self.train_epoch_toggle = False
@@ -74,12 +79,12 @@ class Trainer(_BaseTrainer):
             self.exp.set_prop('debug', True)
 
     @property
-    def db(self):
-        return self._database
+    def metrics(self):
+        return self.metric_board
 
     @property
-    def database(self):
-        return self._database
+    def db(self):
+        return self.database
 
     @property
     def saver(self) -> Saver:
@@ -333,8 +338,14 @@ class Trainer(_BaseTrainer):
                                        trainer_frame=str(func)),
                                   flush=True)
 
-    def initialize(self):
+    @property
+    def is_initialized(self):
         if self._prop.get('initial', False):
+            return True
+        return False
+
+    def initialize(self):
+        if self.is_initialized:
             return
         self.exp.start()
 
@@ -413,6 +424,7 @@ class Trainer(_BaseTrainer):
                 break
 
         self.database.update_dict(dict(end=datetime.now(), finished=True), flush=True)
+        self.database.flush()
         return self._prop
 
     def train_epoch(self, loader: DataLoaderType, params: ParamsType = None,
@@ -427,6 +439,7 @@ class Trainer(_BaseTrainer):
 
         self.wait_for_everyone()
         for idx, batch in enumerate(loader):
+            batch = send_to_device(batch, device=self.device)
             if self.train_epoch_toggle:
                 self.train_epoch_toggle = False
                 break
@@ -440,9 +453,7 @@ class Trainer(_BaseTrainer):
             self._prop['global_steps'] += 1
             metric = self.train_step(batch, params)
             record.record(metric)
-
-        for k, v in record.agg().items():
-            self.share(f'train_epoch.{k}', v)
+            self.database.flush()
 
         record.flush()
         self.database.update_dict(dict(eidx=self.eidx, end=datetime.now()))
@@ -546,13 +557,13 @@ class Trainer(_BaseTrainer):
         record = self.create_record(stage=stage)
         self.wait_for_everyone()
         for idx, batch in enumerate(loader):
+            batch = send_to_device(batch, device=self.device)
             if limit_step is not None and idx >= limit_step:
                 break
             self.set_idx(idx)
             metric = self.test_step(batch, params)
             record.record(metric)
-        for k, v in record.agg().items():
-            self.share(f'test.{k}', v)
+
         record.flush()
         return record
 
@@ -571,13 +582,13 @@ class Trainer(_BaseTrainer):
 
         record = self.create_record(stage=stage)
         for idx, batch in enumerate(loader):
+            batch = send_to_device(batch, device=self.device)
             if limit_step is not None and idx >= limit_step:
                 break
             self.set_idx(idx)
             metric = self.evaluate_step(batch, params)
             record.record(metric)
-        for k, v in record.agg().items():
-            self.share(f'test.{k}', v)
+
         record.flush()
         return record
 
@@ -674,6 +685,3 @@ class Trainer(_BaseTrainer):
                                          is_best=is_best)
         self.wait_for_everyone()
         return val
-
-    def share(self, key, value):
-        self.shared_prop[key] = value
